@@ -5,4 +5,4 @@ def randomInt(fromInt,toInt):
     while toInt != randomTime[index]:
         index = index + 1
         randomTime.append(fromInt - index)
-    return int(random.choice(randomTime))
+    print(int(random.choice(randomTime)))
